import { Container } from '@mui/material';
import { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import MonthCalendarBody from '../../components/MonthCalendarBody/MonthCalendarBody';
import MonthCalendarHeader from '../../components/MonthCalendarHeader/MonthCalendarHeader';
import { fetchTasks, setNewTasksForCells } from '../../store/actions/tasksActions';

function MonthCalendar() {
  const dispatch = useDispatch();
  const { tasks } = useSelector(state => state.tasks);

  const [month, setMonth] = useState('')
  const [year, setYear] = useState('')
  const [worker, setWorker] = useState('');
  const [calendarType, setCalendarType] = useState('Месяц');
  
  useEffect(()=>{
    setMonth(new Date().getMonth())
    setYear(new Date().getFullYear())
    dispatch(fetchTasks())
  }, [dispatch])
  console.log(tasks)
  const onChangeWorkerHandler = (event) => {
    setWorker(event.target.value);
  };

  const onChangeCalendarTypeHandler = (event) => {
    setCalendarType(event.target.value);
  };

  const getCurrentMonthString = (month) => {
    return ["Январь","Февраль","Март","Апрель","Май","Июнь","Июль","Август","Сентябрь","Октябрь","Ноябрь", "Декабрь"][month];
  }

  const getDayOfWeekString = (day) => {
    return ["ВС","ПН","ВТ","СР","ЧТ","ПТ","СБ"][day];
  }

  const getDayOfWeekNumber = (day) => {
    return new Date(year, month, day).getDay()
  }

  const setNewTasksWithInfoForCell = (tasks) => {
    const newArr = tasks.map((task)=>{
      if (task.dateTimeStart && task.dateTimeDue) {
        const dateStart = task.dateTimeStart.split('T')[0]
        const timeStart = task.dateTimeStart.split('T')[1]
        const timeEnd = task.dateTimeDue.split('T')[1]
        const dayStart = parseInt(dateStart.split('-')[2])
        const dayOfWeekStartNumber = getDayOfWeekNumber(dayStart)
        const dayOfWeekStartString = getDayOfWeekString(dayOfWeekStartNumber)
        const monthStartNumber =  parseInt(dateStart.split('-')[1])
        const yearStartNumber =  parseInt(dateStart.split('-')[0])
        const timeStartHour = parseInt(timeStart.split(':')[0])
        const timeEndHour = parseInt(timeEnd.split(':')[0])
        return {...task, 
          startDay: dayStart, 
          startDayOfWeek: dayOfWeekStartString, 
          startHour: timeStartHour, 
          startMonth: monthStartNumber,
          startYear: yearStartNumber,
          endHour: timeEndHour,
        } 
      } 
    })
    dispatch(setNewTasksForCells(newArr))
  }

  const incrementMonth = () => {
    setMonth((prevState)=>{
      if (prevState + 1 === 12 ) { 
        setYear(prevState=>prevState+1)
        return 0 
      }
      return prevState + 1
    })
  }

  const decrementMonth = () => {
    setMonth((prevState)=>{
      if (prevState - 1 === -1) {
        setYear(prevState=>prevState-1)
        return 11
      }
      return prevState - 1 
    })
  }

  return (
    <>
    <Container>
      <MonthCalendarHeader
        month={month}
        year={year}
        getCurrentMonthString={getCurrentMonthString} 
        decrementMonth={decrementMonth}
        incrementMonth={incrementMonth}
        onChangeCalendarTypeHandler={onChangeCalendarTypeHandler}
        onChangeWorkerHandler={onChangeWorkerHandler}
        worker={worker}
        calendarType={calendarType}
      />
      <MonthCalendarBody
        month={month}
        year={year}
        tasks={tasks}
      />
    </Container>
    </>
  );
}

export default MonthCalendar;
